@@ -1,26 +1,25 @@
-use 5.16.0;
+use 5.10.0;
 use strict;
 use warnings;
 
-package Map::Metro::Plugin::Map::Helsinki  {
+package Map::Metro::Plugin::Map::Helsinki;
 
-    our $VERSION = '0.1985'; # VERSION
-    # ABSTRACT: Map::Metro map for Helsinki
+# ABSTRACT: Map::Metro map for Helsinki
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1987';
 
-    use Moose;
-    with 'Map::Metro::Plugin::Map';
+use Moose;
+with 'Map::Metro::Plugin::Map';
 
-    has '+mapfile' => (
-        default => 'map-helsinki.metro',
-    );
-    sub map_version {
-        return $VERSION;
-    }
-    sub map_package {
-        return __PACKAGE__;
-    }
+has '+mapfile' => (
+    default => 'map-helsinki.metro',
+);
+sub map_version {
+    return $VERSION;
+}
+sub map_package {
+    return __PACKAGE__;
 }
-
 
 1;
 
@@ -36,22 +35,21 @@ Map::Metro::Plugin::Map::Helsinki - Map::Metro map for Helsinki
 
 
 
-=begin HTML
+=begin html
 
-<p><img src="https://img.shields.io/badge/perl-5.16+-brightgreen.svg" alt="Requires Perl 5.16+" /> <a href="https://travis-ci.org/Csson/p5-Map-Metro-Helsinki"><img src="https://api.travis-ci.org/Csson/p5-Map-Metro-Helsinki.svg?branch=master" alt="Travis status" /></a></p>
+<p>
+<img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
+<a href="https://travis-ci.org/Csson/p5-Map-Metro-Helsinki"><img src="https://api.travis-ci.org/Csson/p5-Map-Metro-Helsinki.svg?branch=master" alt="Travis status" /></a>
+<a href="http://cpants.cpanauthors.org/release/CSSON/Map-Metro-Plugin-Map-Helsinki-0.1987"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/Map-Metro-Plugin-Map-Helsinki/0.1987" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Map-Metro-Plugin-Map-Helsinki%200.1987"><img src="http://badgedepot.code301.com/badge/cpantesters/Map-Metro-Plugin-Map-Helsinki/0.1987" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-88.2%-orange.svg" alt="coverage 88.2%" />
+</p>
 
-=end HTML
-
-
-=begin markdown
-
-![Requires Perl 5.16+](https://img.shields.io/badge/perl-5.16+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Map-Metro-Helsinki.svg?branch=master)](https://travis-ci.org/Csson/p5-Map-Metro-Helsinki)
-
-=end markdown
+=end html
 
 =head1 VERSION
 
-Version 0.1985, released 2015-04-26.
+Version 0.1987, released 2016-10-30.
 
 =head1 SYNOPSIS
 
@@ -98,7 +96,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
